﻿//*****************************************************************************
// Description     : Definition of IO functions
// Target Device   : APU101
// Target Platform : Windows, .NET Framework, C++
// Date            : July 2017
// Version         : 1.0
//*****************************************************************************
#include "file.h"

using namespace System;
using namespace System::IO;


//#########################################################################
//  Name      : file_write_header
//  Function  : write header to the text file
//  Arguments :
//      in pName    : file name
//      in now_time : actual measurement time(msec)
//      in in_cps   : input count rate(cps)
//      in th_cps   : throughput count rate(cps)
//  Return :
//       0 : success
//      -1 : failed to open file
//#########################################################################
int file_write_header(String ^pName, unsigned int now_time,
                      unsigned int in_cps, unsigned int th_cps)
{
    try {
        // open file(create)
        StreamWriter ^writer = File::CreateText(pName);

        // write header information
        try {
            writer->WriteLine("[header]");
            writer->WriteLine("Real time(s), {0}", now_time/1000);
            writer->WriteLine("Input rate(cps), {0}", in_cps);
            writer->WriteLine("Throughput rate(cps), {0}", th_cps);
        }
        finally
        {
            if (writer) {
                delete (IDisposable^)writer;
            }
        }

    }
    catch (Exception ^e) {
        // failed to open file
        return(-1);
    }

    return(0);
}


//#########################################################################
//  Name      : file_write_data
//  Function  : write data to the text file
//  Arguments :
//      in pName : file name
//      in nbyte : size of the data(byte)
//      in pBuff : pointer to the data buffer
//  Return :
//       0 : success
//      -1 : failed to open file
//#########################################################################
int file_write_data(String ^pName, int nbyte, void *pBuff)
{
    int i;
    unsigned int *p;
    int unit = nbyte;

    try {
        // open file(append)
        StreamWriter ^writer = File::AppendText(pName);

        // write data
        try {
            p = (unsigned int *)pBuff;
            unit = nbyte / sizeof(unsigned int);

            writer->WriteLine("[data]");
            for (i = 0; i < unit; i++, p++) {
                writer->WriteLine(*p);
            }
        }
        finally
        {
            if (writer) {
                delete (IDisposable^)writer;
            }
        }
    }
    catch (Exception ^e) {
        // failed to open file
        return(-1);
    }

    return(i);
}
